# Kubernetes Monitoring Helm Chart Installation Guide

This guide provides instructions for installing the monitoring components for your Kubernetes clusters using Helm. You'll first install the CRDs (Custom Resource Definitions), then create and customize the `values.yaml` file with your specific configuration, and finally install the main monitoring chart.

## Step 1: Install the CRDs Chart

Before deploying the monitoring chart, you need to install the required CRDs. Run the following command to install the CRDs:

```bash
helm install monitoring-crds https://gitlab.cern.ch/monitoring/helm-charts/kubernetes-monitoring-crds/-/archive/v0.1.0/kubernetes-monitoring-crds-v0.1.0.tar.gz -n monitoring
```

This command installs the necessary CRDs in the monitoring namespace.

## Step 2: Create and Customize the values.yaml File

Next, you need to create a values.yaml file, which contains the configuration for your monitoring setup. Customize the content of this file to match your specific environment.

```bash
cat <<EOF > values.yaml
tenant:
  name: <tenant_name>
  password: <password>
kubernetes:
  clusterName: <cluster_name>
logs:
  enabled: true
  fluentbit:
    enabled: true
EOF
```

Replace the placeholders (`<tenant_name>`, `<password>`, `<cluster_name>`) with your actual tenant name, password, and Kubernetes cluster name. If you do not have one contact the CERN IT Monitoring Team.

## Step 3: Install the Monitoring Chart

With the CRDs installed and the values.yaml file configured, you can now install the main monitoring chart:

```bash
helm install monitoring https://gitlab.cern.ch/monitoring/helm-charts/kubernetes-monitoring/-/archive/v0.1.1/kubernetes-monitoring-v0.1.1.tar.gz -n monitoring -f values.yaml
```

This command deploys the monitoring components to the monitoring namespace using the settings specified in your `values.yaml` file.

## Summary

- **Step 1**: Install the CRDs chart.
- **Step 2**: Create and customize the values.yaml file.
- **Step 3**: Install the monitoring chart.

Your monitoring setup should now be successfully deployed to your Kubernetes cluster. To confirm that you can check the logs of the metrics and logs collectors, no errors should be raised in the logs.